@@ -10,7 +10,7 @@ use utils::parse;
 
 const EXCHANGE_NAME: &str = "bybit";
 
-#[test_case(MarketType::InverseFuture, "BTCUSDZ21")]
+#[test_case(MarketType::InverseFuture, "BTCUSDM22")]
 #[test_case(MarketType::InverseSwap, "BTCUSD")]
 #[test_case(MarketType::LinearSwap, "BTCUSDT")]
 fn test_crawl_trade(market_type: MarketType, symbol: &str) {
@@ -23,7 +23,7 @@ fn test_crawl_trade(market_type: MarketType, symbol: &str) {
     )
 }
 
-#[test_case(MarketType::InverseFuture, "BTCUSDZ21")]
+#[test_case(MarketType::InverseFuture, "BTCUSDM22")]
 #[test_case(MarketType::InverseSwap, "BTCUSD")]
 #[test_case(MarketType::LinearSwap, "BTCUSDT")]
 fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
@@ -36,20 +36,7 @@ fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
     )
 }
 
-#[test_case(MarketType::InverseFuture, "BTCUSDZ21")]
-#[test_case(MarketType::InverseSwap, "BTCUSD")]
-#[test_case(MarketType::LinearSwap, "BTCUSDT")]
-fn test_crawl_l2_topk(market_type: MarketType, symbol: &str) {
-    test_one_symbol!(
-        crawl_l2_topk,
-        EXCHANGE_NAME,
-        market_type,
-        symbol,
-        MessageType::L2TopK
-    )
-}
-
-#[test_case(MarketType::InverseFuture, "BTCUSDZ21")]
+#[test_case(MarketType::InverseFuture, "BTCUSDM22")]
 #[test_case(MarketType::InverseSwap, "BTCUSD")]
 #[test_case(MarketType::LinearSwap, "BTCUSDT")]
 fn test_crawl_l2_snapshot(market_type: MarketType, symbol: &str) {
@@ -74,7 +61,7 @@ fn test_crawl_l2_snapshot_without_symbol(market_type: MarketType) {
     )
 }
 
-#[test_case(MarketType::InverseFuture, "BTCUSDZ21")]
+#[test_case(MarketType::InverseFuture, "BTCUSDM22")]
 #[test_case(MarketType::InverseSwap, "BTCUSD")]
 #[test_case(MarketType::LinearSwap, "BTCUSDT")]
 fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
@@ -94,7 +81,7 @@ fn test_crawl_candlestick(market_type: MarketType) {
     gen_test_crawl_candlestick!(EXCHANGE_NAME, market_type)
 }
 
-#[test_case(MarketType::InverseFuture, "BTCUSDZ21")]
+#[test_case(MarketType::InverseFuture, "BTCUSDM22")]
 #[test_case(MarketType::InverseSwap, "BTCUSD")]
 #[test_case(MarketType::LinearSwap, "BTCUSDT")]
 fn test_subscribe_symbol(market_type: MarketType, symbol: &str) {
